Crate minlin

Crate minlin 

Macros

Array
Tuple
impl_add
impl_add_assign
impl_c_add
impl_c_add_assign
impl_c_neg
impl_c_not
impl_c_sub
impl_c_sub_assign
impl_cast
impl_const_traits
impl_convert
impl_infinity
impl_limits
impl_map_traits
impl_neg_infinity
impl_normal_limits
impl_one
impl_s_div
impl_s_div_assign
impl_s_mul
impl_s_mul_assign
impl_s_rem
impl_s_rem_assign
impl_scale
impl_traits
impl_two
impl_vec_traits
impl_zero
second

Structs

Mat2
Padding
Type that represents padding.
Rect
Rectangle.
Rgba
Vec2
Represents two dimensional vector. Can be used as vector, point, size or any tuple-like object where vector math operations are benefit.
Vec3
Represents three dimensional vector. Can be also use as color or any 3-tuple-like object where vector operations are benefit.
Vec4
Four dimensional vector or any 4-tuple-like object (e.g. rectangle).
Vec2RangeIter
Iterator over 2D area.
Vec3RangeIter
Iterator over 3D volume.

Traits

Cast
Cast type to numeric type with smaller range. Ignore potential overflows.
Checked
Generic trait for types that support saturating arithmetic.
CompArithm
Trait for componentwise arithmetic.
ContainingFloat
Trait for integers. For each interger, it uses the smallest float that can contain all value of the integer loslessly.
Convert
Float
Goniometric
Trait that allows calculation of goniometric functions.
Infinity
Represents types that can represent the value of infinity.
IntoFloat
Isqrt
Calculate the integer square root.
LargeType
Represents type that has larger type for operations that may be outside of normal values.
Limits
Implements number limits.
MapExt
Trait for types that can be mapped.
NegInfinity
Represents types that can represent the value of negative infinity.
NormalLimits
Contains constants limiting the value to normal range.
One
RangeExt
Trait for types that can represent range.
RectExt
Saturating
Generic trait for types that support saturating arithmetic.
Scale
Sqrt
Calculate the floating point square root.
Two
TwoComponent
Trait that represents types that have two components.
Zero