RectExt

Trait RectExt 

pub trait RectExt: Sized {
    type Val: Copy + Add<Output = Self::Val> + Sub<Output = Self::Val> + PartialOrd;

Show 46 methods // Required methods fn from_pos_size( pos: impl Into<Vec2<Self::Val>>, size: impl Into<Vec2<Self::Val>>, ) -> Self; fn width(&self) -> Self::Val; fn height(&self) -> Self::Val; fn x(&self) -> Self::Val; fn y(&self) -> Self::Val; fn set_width(&mut self, w: Self::Val); fn set_height(&mut self, h: Self::Val); fn set_x(&mut self, x: Self::Val); fn set_y(&mut self, y: Self::Val); // Provided methods fn from_ranges( lr: impl Into<Range<Self::Val>>, tb: impl Into<Range<Self::Val>>, ) -> Self { ... } fn from_points( a: impl Into<Vec2<Self::Val>>, b: impl Into<Vec2<Self::Val>>, ) -> Self { ... } fn pos(&self) -> Vec2<Self::Val> { ... } fn size(&self) -> Vec2<Self::Val> { ... } fn left(&self) -> Self::Val { ... } fn top(&self) -> Self::Val { ... } fn right(&self) -> Self::Val { ... } fn bottom(&self) -> Self::Val { ... } fn top_left(&self) -> Vec2<Self::Val> { ... } fn top_right(&self) -> Vec2<Self::Val> { ... } fn bot_right(&self) -> Vec2<Self::Val> { ... } fn bot_left(&self) -> Vec2<Self::Val> { ... } fn xrange(&self) -> Range<Self::Val> { ... } fn yrange(&self) -> Range<Self::Val> { ... } fn center(&self) -> Vec2<Self::Val> where Self::Val: Div<Output = Self::Val> + Two { ... } fn pad_rect(&self, padding: impl Into<Padding<Self::Val>>) -> Self where Self::Val: PartialOrd + Zero { ... } fn extend_rect(&self, margin: impl Into<Padding<Self::Val>>) -> Self { ... } fn bound_join(&self, other: impl Into<Self>) -> Self { ... } fn intersect(&self, other: impl Into<Self>) -> Self { ... } fn move_to(&mut self, pos: impl Into<Vec2<Self::Val>>) -> &mut Self { ... } fn encloses(&self, other: &Self) -> bool { ... } fn contains(&self, point: impl Into<Vec2<Self::Val>>) -> bool { ... } fn intersects(&self, other: &Self) -> bool { ... } fn area(&self) -> Self::Val where Self::Val: Mul<Output = Self::Val> { ... } fn is_empty(&self) -> bool where Self::Val: PartialEq + Zero { ... } fn clamp(&self, pt: impl Into<Vec2<Self::Val>>) -> Vec2<Self::Val> { ... } fn set_pos(&mut self, pos: impl Into<Vec2<Self::Val>>) { ... } fn set_size(&mut self, size: impl Into<Vec2<Self::Val>>) { ... } fn extend_bot(&mut self, amt: Self::Val) { ... } fn extend_right(&mut self, amt: Self::Val) { ... } fn extend_left(&mut self, amt: Self::Val) { ... } fn extend_top(&mut self, amt: Self::Val) { ... } fn moved_by(&self, amt: impl Into<Vec2<Self::Val>>) -> Self { ... } fn set_right(&mut self, r: Self::Val) { ... } fn set_left(&mut self, l: Self::Val) { ... } fn set_bottom(&mut self, b: Self::Val) { ... } fn set_top(&mut self, t: Self::Val) { ... }
}

Required Associated Types

type Val: Copy + Add<Output = Self::Val> + Sub<Output = Self::Val> + PartialOrd

Required Methods

fn from_pos_size( pos: impl Into<Vec2<Self::Val>>, size: impl Into<Vec2<Self::Val>>, ) -> Self

Create new rectangle from position of top left corner and size.

fn width(&self) -> Self::Val

Get the width of the rectangle.

fn height(&self) -> Self::Val

Get the height of the rectangle.

fn x(&self) -> Self::Val

Get the x coordinate of the rectangle.

fn y(&self) -> Self::Val

Get the y coordinate of the rectangle.

fn set_width(&mut self, w: Self::Val)

Set the width of the rectangle.

fn set_height(&mut self, h: Self::Val)

Set the height of the rectangle.

fn set_x(&mut self, x: Self::Val)

Set the x coordinate of the rectangle.

fn set_y(&mut self, y: Self::Val)

Set the y coordinate of the rectangle.

Provided Methods

fn from_ranges( lr: impl Into<Range<Self::Val>>, tb: impl Into<Range<Self::Val>>, ) -> Self

Create the rectangle from ranges of coordinates.

fn from_points( a: impl Into<Vec2<Self::Val>>, b: impl Into<Vec2<Self::Val>>, ) -> Self

Create the rectangle from two points.

fn pos(&self) -> Vec2<Self::Val>

Get the position of the rectangle.

fn size(&self) -> Vec2<Self::Val>

Get the size of the rectangle.

fn left(&self) -> Self::Val

Get the left coordinate of the rectangle.

fn top(&self) -> Self::Val

Get the top coordinate of the rectangle.

fn right(&self) -> Self::Val

Get the right coordinate of the rectangle.

fn bottom(&self) -> Self::Val

Get the bottom coordinate of the rectangle.

fn top_left(&self) -> Vec2<Self::Val>

Get the top left corner position.

fn top_right(&self) -> Vec2<Self::Val>

Get the top right corner position.

fn bot_right(&self) -> Vec2<Self::Val>

Get the bottom right corner position.

fn bot_left(&self) -> Vec2<Self::Val>

Get the bottom left corner position.

fn xrange(&self) -> Range<Self::Val>

Get the range in x coordinate.

fn yrange(&self) -> Range<Self::Val>

Get the range in y coordinate.

fn center(&self) -> Vec2<Self::Val>
where Self::Val: Div<Output = Self::Val> + Two,

Get the center of the rectangle.

fn pad_rect(&self, padding: impl Into<Padding<Self::Val>>) -> Self
where Self::Val: PartialOrd + Zero,

Shrink the rectangle with padding.

fn extend_rect(&self, margin: impl Into<Padding<Self::Val>>) -> Self

Enlarge the rectangle with the given padding.

fn bound_join(&self, other: impl Into<Self>) -> Self

Create rectangle that encloses both of the rectangles.

fn intersect(&self, other: impl Into<Self>) -> Self

Create rectangle that is the intersection of two rectangles.

fn move_to(&mut self, pos: impl Into<Vec2<Self::Val>>) -> &mut Self

Change the position of the rectangle.

fn encloses(&self, other: &Self) -> bool

Check whether this rectangle fully encloses the other rectangle.

fn contains(&self, point: impl Into<Vec2<Self::Val>>) -> bool

Check whether this rectangle contains the given point.

fn intersects(&self, other: &Self) -> bool

Check whether two rectangles intersect.

fn area(&self) -> Self::Val
where Self::Val: Mul<Output = Self::Val>,

Get the area of the rectangle.

fn is_empty(&self) -> bool
where Self::Val: PartialEq + Zero,

Check whether the rectangle is empty.

fn clamp(&self, pt: impl Into<Vec2<Self::Val>>) -> Vec2<Self::Val>

Clamp the point to be contained in the rectangle.

fn set_pos(&mut self, pos: impl Into<Vec2<Self::Val>>)

Sets the position to the given value.

fn set_size(&mut self, size: impl Into<Vec2<Self::Val>>)

Sets the size of the rectangle.

fn extend_bot(&mut self, amt: Self::Val)

Extend the rectangle from bottom by the given amount.

fn extend_right(&mut self, amt: Self::Val)

Extend the rectangle from right by the given amount.

fn extend_left(&mut self, amt: Self::Val)

Extend the rectangle from left by the given amount.

fn extend_top(&mut self, amt: Self::Val)

Extend the rectangle from left by the given amount.

fn moved_by(&self, amt: impl Into<Vec2<Self::Val>>) -> Self

Create new rectangle moved by the given amount.

fn set_right(&mut self, r: Self::Val)

Set the right value.

fn set_left(&mut self, l: Self::Val)

Set the left value.

fn set_bottom(&mut self, b: Self::Val)

Set the bottom value.

fn set_top(&mut self, t: Self::Val)

Set the top value.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T> RectExt for Rect<T>
where T: Copy + Add<Output = T> + Sub<Output = T> + PartialOrd,

Source

type Val = T

Source

impl<T> RectExt for Vec4<T>
where T: Copy + Add<Output = T> + Sub<Output = T> + PartialOrd,

Source

type Val = T