Macros
- Array
- Tuple
- impl_
add - impl_
add_ assign - impl_
c_ add - impl_
c_ add_ assign - impl_
c_ neg - impl_
c_ not - impl_
c_ sub - impl_
c_ sub_ assign - impl_
cast - impl_
const_ traits - impl_
convert - impl_
infinity - impl_
limits - impl_
map_ traits - impl_
neg_ infinity - impl_
normal_ limits - impl_
one - impl_
s_ div - impl_
s_ div_ assign - impl_
s_ mul - impl_
s_ mul_ assign - impl_
s_ rem - impl_
s_ rem_ assign - impl_
scale - impl_
traits - impl_
two - impl_
vec_ traits - impl_
zero - second
Structs
- Mat2
- Padding
- Type that represents padding.
- Rect
- Rectangle.
- Rgba
- Vec2
- Represents two dimensional vector. Can be used as vector, point, size or any tuple-like object where vector math operations are benefit.
- Vec3
- Represents three dimensional vector. Can be also use as color or any 3-tuple-like object where vector operations are benefit.
- Vec4
- Four dimensional vector or any 4-tuple-like object (e.g. rectangle).
- Vec2
Range Iter - Iterator over 2D area.
- Vec3
Range Iter - Iterator over 3D volume.
Traits
- Cast
- Cast type to numeric type with smaller range. Ignore potential overflows.
- Checked
- Generic trait for types that support saturating arithmetic.
- Comp
Arithm - Trait for componentwise arithmetic.
- Containing
Float - Trait for integers. For each interger, it uses the smallest float that can contain all value of the integer loslessly.
- Convert
- Float
- Goniometric
- Trait that allows calculation of goniometric functions.
- Infinity
- Represents types that can represent the value of infinity.
- Into
Float - Isqrt
- Calculate the integer square root.
- Large
Type - Represents type that has larger type for operations that may be outside of normal values.
- Limits
- Implements number limits.
- MapExt
- Trait for types that can be mapped.
- NegInfinity
- Represents types that can represent the value of negative infinity.
- Normal
Limits - Contains constants limiting the value to normal range.
- One
- Range
Ext - Trait for types that can represent range.
- RectExt
- Saturating
- Generic trait for types that support saturating arithmetic.
- Scale
- Sqrt
- Calculate the floating point square root.
- Two
- TwoComponent
- Trait that represents types that have two components.
- Zero